Package 'repboxTableTools'

Title: Tools to characterize, test and repair extracted tables from articles
Description: While ExtractSciTab is only about heuristically extracting tables from PDF, this package contains helper function to characterize test and repair multiple versions of extracted tables (including AI extraction methods). It mainly complements repboxAI. To avoid that repboxAI becomes too gluttered, we put this into a separate package.
Authors: Sebastian Kranz
Maintainer: Sebastian Kranz <[email protected]>
License: GPL >= 2.0
Version: 0.1.0
Built: 2026-05-11 09:41:46 UTC
Source: https://github.com/repboxr/repboxTableTools

Help Index